using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Text;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace FontXplorer
{
    public partial class Form1 : Form
    {

        //private vars
        PrivateFontCollection pfc = new PrivateFontCollection();
        System.Drawing.Font font;
        MyAboutBox myaboutbox;
        
        private static string[] allCharStrings = new string[]{
            "The quick brown fox jumps over the lazy dog. 0123456789.\r\n\r\n",
            "Jackdaws love my big sphinx of quartz. 0123456789.\r\n\r\n",
            "Questions of a zealous nature have become by degrees pretty waxen jokes. 0123456789.\r\n\r\n"
        };

        Random rand = new Random();

        public Form1() {
            InitializeComponent();
        }

        
        private void btnBrowse_Click(object sender, EventArgs e) {
            if (folderBrowserDialog1.ShowDialog(this) == DialogResult.OK) {
                txtFolderPath.Text = folderBrowserDialog1.SelectedPath;
            }
        }

        private void btnRefresh_Click(object sender, EventArgs e) {
            if (Directory.Exists(txtFolderPath.Text)) {
                string[] filenames = null;

                if (chkSubFolders.Checked) {
                    filenames = Directory.GetFiles(txtFolderPath.Text, "*.ttf",
                        SearchOption.AllDirectories);
                }
                else {
                    filenames = Directory.GetFiles(txtFolderPath.Text, "*.ttf",
                        SearchOption.TopDirectoryOnly);
                }

                if (filenames.Length < 1) {
                    toolStripStatusLabel1.Text = "Selected folder contains no ttf files.";
                }

                //show the progress bar.
                toolStripStatusLabel1.Text = "Loading fonts...";
                toolStripProgressBar1.Visible = true;
                int totalFiles = filenames.Length;

                richTextBox1.Clear();

                if (pfc.Families.Length > 0) {
                    //dispose it
                    pfc.Dispose();
                    //and create it afresh
                    pfc = new PrivateFontCollection();
                }

                lstFonts.Items.Clear();
                for (int i = 0; i < filenames.Length; i++) {
                    pfc.AddFontFile(filenames[i]);
                    toolStripProgressBar1.Value = (i * 100 / totalFiles);
                }

                toolStripProgressBar1.Visible = false;


                //Now add the family names to the list box..
                for (int i = 0; i < pfc.Families.Length; i++) {
                    lstFonts.Items.Add(pfc.Families[i].Name);                    
                }

                toolStripStatusLabel1.Text = filenames.Length+" font files loaded.";
            }
            else {
                toolStripStatusLabel1.Text = "Selected path is not a folder.";
            }
        }


        private void lstFonts_SelectedIndexChanged(object sender, EventArgs e) {
            FontFamily f = null;
            if(pfc.Families.Length>0)
                f = pfc.Families[lstFonts.SelectedIndex];

            FontStyle style = FontStyle.Regular;
            if (!f.IsStyleAvailable(FontStyle.Regular)) {
                if (f.IsStyleAvailable(FontStyle.Italic)) {
                    style = FontStyle.Italic;
                }
                else if (f.IsStyleAvailable(FontStyle.Bold)) {
                    style = FontStyle.Bold;
                }
                else if (f.IsStyleAvailable(FontStyle.Underline)) {
                    style = FontStyle.Underline;
                }
                else if (f.IsStyleAvailable(FontStyle.Strikeout)) {
                    style = FontStyle.Strikeout;
                }
                else if (f.IsStyleAvailable(FontStyle.Bold | FontStyle.Italic)) {
                    style = FontStyle.Bold | FontStyle.Italic;
                }
                else {
                    richTextBox1.Text = "Error: Font not supported.";
                    toolStripStatusLabel1.Text = "Not supported!";
                    return;
                }
            }


            font = new Font(f, 30, style);
            int displayStringIndex = rand.Next(allCharStrings.Length);

            richTextBox1.Clear();
            richTextBox1.Font = font;
            richTextBox1.SelectionFont = new Font(f, 10, style);
            richTextBox1.AppendText(allCharStrings[displayStringIndex]);

            richTextBox1.SelectionFont = new Font(f, 20, style);
            richTextBox1.AppendText(allCharStrings[displayStringIndex]);

            richTextBox1.SelectionFont = new Font(f, 30, style);
            richTextBox1.AppendText(allCharStrings[displayStringIndex]);

            
            toolStripStatusLabel1.Text = "Font Displayed.";
            
            
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e) {
            Application.Exit();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e) {
            if (myaboutbox == null) {
                myaboutbox = new MyAboutBox();
            }
            myaboutbox.ShowDialog(this);
        }



    }

}